@@ -26,13 +26,13 @@ from ._forms import (
     MessageMixin,
     SuccessURLRedirectListMixin,
     UserFormKwargsMixin,
-    _MessageAPIWrapper
 )
 from ._other import (
     AllVerbsMixin,
     CanonicalSlugDetailMixin,
     SetHeadlineMixin,
-    StaticContextMixin
+    StaticContextMixin,
+    HeaderMixin
 )
 from ._queries import (
     OrderableListMixin,
@@ -50,6 +50,7 @@ __all__ = [
     'FormMessagesMixin',
     'FormValidMessageMixin',
     'GroupRequiredMixin',
+    'HeaderMixin',
     'JSONRequestResponseMixin',
     'JsonRequestResponseMixin',
     'JSONResponseMixin',
