@@ -1,3 +1,5 @@
+import warnings
+
 from django.core.exceptions import ImproperlyConfigured
 
 
@@ -9,8 +11,8 @@ class SelectRelatedMixin(object):
     select_related = None  # Default related fields to none
 
     def get_queryset(self):
-        if self.select_related is None:  # If no fields were provided,
-                                         # raise a configuration error
+        if self.select_related is None:
+            # If no fields were provided, raise a configuration error
             raise ImproperlyConfigured(
                 '{0} is missing the select_related property. This must be '
                 'a tuple or list.'.format(self.__class__.__name__))
@@ -26,7 +28,9 @@ class SelectRelatedMixin(object):
         queryset = super(SelectRelatedMixin, self).get_queryset()
 
         if not self.select_related:
+            warnings.warn('The select_related attribute is empty')
             return queryset
+
         return queryset.select_related(*self.select_related)
 
 
@@ -38,8 +42,8 @@ class PrefetchRelatedMixin(object):
     prefetch_related = None  # Default prefetch fields to none
 
     def get_queryset(self):
-        if self.prefetch_related is None:  # If no fields were provided,
-                                           # raise a configuration error
+        if self.prefetch_related is None:
+            # If no fields were provided, raise a configuration error
             raise ImproperlyConfigured(
                 '{0} is missing the prefetch_related property. This must be '
                 'a tuple or list.'.format(self.__class__.__name__))
@@ -55,7 +59,9 @@ class PrefetchRelatedMixin(object):
         queryset = super(PrefetchRelatedMixin, self).get_queryset()
 
         if not self.prefetch_related:
+            warnings.warn('The prefetch_related attribute is empty')
             return queryset
+
         return queryset.prefetch_related(*self.prefetch_related)
 
 
@@ -66,6 +72,7 @@ class OrderableListMixin(object):
 
     orderable_columns = None
     orderable_columns_default = None
+    ordering_default = None
     order_by = None
     ordering = None
 
@@ -95,6 +102,16 @@ class OrderableListMixin(object):
                     self.__class__.__name__))
         return self.orderable_columns_default
 
+    def get_ordering_default(self):
+        if not self.ordering_default:
+            return "asc"
+        else:
+            if self.ordering_default not in ["asc", "desc"]:
+                raise ImproperlyConfigured(
+                    '{0} only allows asc or desc as ordering option'.format(
+                        self.__class__.__name__))
+            return self.ordering_default
+
     def get_ordered_queryset(self, queryset=None):
         """
         Augments ``QuerySet`` with order_by statement if possible
@@ -110,11 +127,12 @@ class OrderableListMixin(object):
             order_by = self.get_orderable_columns_default()
 
         self.order_by = order_by
-        self.ordering = "asc"
+        self.ordering = self.get_ordering_default()
 
-        if order_by and self.request.GET.get("ordering", "asc") == "desc":
+        if order_by and self.request.GET.get(
+                "ordering", self.ordering) == "desc":
             order_by = "-" + order_by
-            self.ordering = "desc"
+        self.ordering = self.request.GET.get("ordering", self.ordering)
 
         return queryset.order_by(order_by)
 
