@@ -40,22 +40,12 @@ class UserFactory(factory.django.DjangoModelFactory):
     first_name = factory.Sequence(lambda n: 'John {0}'.format(n))
     last_name = factory.Sequence(lambda n: 'Doe {0}'.format(n))
     email = factory.Sequence(lambda n: 'user{0}@example.com'.format(n))
-    password = 'asdf1234'
+    password = factory.PostGenerationMethodCall('set_password', 'asdf1234')
 
     class Meta:
         model = User
         abstract = False
 
-    @classmethod
-    def _prepare(cls, create, **kwargs):
-        password = kwargs.pop('password', None)
-        user = super(UserFactory, cls)._prepare(create, **kwargs)
-        if password:
-            user.set_password(password)
-            if create:
-                user.save()
-        return user
-
     @factory.post_generation
     def permissions(self, create, extracted, **kwargs):
         if create and extracted:
