@@ -2,14 +2,24 @@ from django.db import models
 
 
 class Article(models.Model):
-    author = models.ForeignKey('auth.User', null=True, blank=True)
+    author = models.ForeignKey(
+        'auth.User',
+        null=True,
+        blank=True,
+        on_delete=models.CASCADE
+    )
     title = models.CharField(max_length=30)
     body = models.TextField()
     slug = models.SlugField(blank=True)
 
 
 class CanonicalArticle(models.Model):
-    author = models.ForeignKey('auth.User', null=True, blank=True)
+    author = models.ForeignKey(
+        'auth.User',
+        null=True,
+        blank=True,
+        on_delete=models.CASCADE
+    )
     title = models.CharField(max_length=30)
     body = models.TextField()
     slug = models.SlugField(blank=True)
@@ -18,4 +28,3 @@ class CanonicalArticle(models.Model):
         if self.author:
             return "{0.author.username}-{0.slug}".format(self)
         return "unauthored-{0.slug}".format(self)
-
