@@ -1,17 +1,22 @@
 # -*- coding: utf-8 -*-
 from __future__ import absolute_import, unicode_literals
 
-import pytest
 import datetime
 
+import pytest
+
 from django import test
-from django import VERSION as DJANGO_VERSION
 from django.test.utils import override_settings
 from django.core.exceptions import ImproperlyConfigured, PermissionDenied
-from django.core.urlresolvers import reverse_lazy
 from django.http import Http404, HttpResponse
+from django.utils.timezone import make_aware, get_current_timezone
 
-from .compat import force_text
+try:
+    from django.urls import reverse_lazy
+except ImportError:
+    from django.core.urlresolvers import reverse_lazy
+
+from .compat import force_string
 from .factories import GroupFactory, UserFactory
 from .helpers import TestViewHelper
 from .views import (PermissionRequiredView, MultiplePermissionsRequiredView,
@@ -22,6 +27,7 @@ from .views import (PermissionRequiredView, MultiplePermissionsRequiredView,
                     UserPassesTestLoginRequiredView)
 
 
+@pytest.mark.django_db
 class _TestAccessBasicsMixin(TestViewHelper):
     """
     A set of basic tests for access mixins.
@@ -48,7 +54,7 @@ class _TestAccessBasicsMixin(TestViewHelper):
         self.client.login(username=user.username, password='asdf1234')
         resp = self.client.get(self.view_url)
         self.assertEqual(200, resp.status_code)
-        self.assertEqual('OK', force_text(resp.content))
+        self.assertEqual('OK', force_string(resp.content))
 
     def test_redirects_to_login(self):
         """
@@ -110,7 +116,7 @@ class _TestAccessBasicsMixin(TestViewHelper):
 
         resp = self.dispatch_view(req, raise_exception=func)
         assert resp.status_code == 200
-        assert force_text(resp.content) == 'CUSTOM'
+        assert force_string(resp.content) == 'CUSTOM'
 
     def test_raise_func_false(self):
         """
@@ -216,6 +222,7 @@ class _TestAccessBasicsMixin(TestViewHelper):
                 redirect_unauthenticated_users=False)
 
 
+@pytest.mark.django_db
 class TestLoginRequiredMixin(TestViewHelper, test.TestCase):
     """
     Tests for LoginRequiredMixin.
@@ -237,7 +244,7 @@ class TestLoginRequiredMixin(TestViewHelper, test.TestCase):
         self.client.login(username=user.username, password='asdf1234')
         resp = self.client.get(self.view_url)
         assert resp.status_code == 200
-        assert force_text(resp.content) == 'OK'
+        assert force_string(resp.content) == 'OK'
 
     def test_anonymous_redirects(self):
         resp = self.dispatch_view(
@@ -247,6 +254,7 @@ class TestLoginRequiredMixin(TestViewHelper, test.TestCase):
         assert resp['Location'] == '/accounts/login/?next=/login_required/'
 
 
+@pytest.mark.django_db
 class TestChainedLoginRequiredMixin(TestViewHelper, test.TestCase):
     """
     Tests for LoginRequiredMixin combined with another AccessMixin.
@@ -304,6 +312,7 @@ class TestChainedLoginRequiredMixin(TestViewHelper, test.TestCase):
         self.assert_redirect_to_login(resp)
 
 
+@pytest.mark.django_db
 class TestAnonymousRequiredMixin(TestViewHelper, test.TestCase):
     """
     Tests for AnonymousRequiredMixin.
@@ -318,14 +327,14 @@ class TestAnonymousRequiredMixin(TestViewHelper, test.TestCase):
         """
         resp = self.client.get(self.view_url)
         self.assertEqual(200, resp.status_code)
-        self.assertEqual('OK', force_text(resp.content))
+        self.assertEqual('OK', force_string(resp.content))
 
         # Test with reverse_lazy
         resp = self.dispatch_view(
             self.build_request(),
             login_url=reverse_lazy(self.view_url))
         self.assertEqual(200, resp.status_code)
-        self.assertEqual('OK', force_text(resp.content))
+        self.assertEqual('OK', force_string(resp.content))
 
     def test_authenticated(self):
         """
@@ -355,6 +364,7 @@ class TestAnonymousRequiredMixin(TestViewHelper, test.TestCase):
         self.assertEqual(404, resp.status_code)
 
 
+@pytest.mark.django_db
 class TestPermissionRequiredMixin(_TestAccessBasicsMixin, test.TestCase):
     """
     Tests for PermissionRequiredMixin.
@@ -377,6 +387,7 @@ class TestPermissionRequiredMixin(_TestAccessBasicsMixin, test.TestCase):
             self.dispatch_view(self.build_request(), permission_required=None)
 
 
+@pytest.mark.django_db
 class TestMultiplePermissionsRequiredMixin(
         _TestAccessBasicsMixin, test.TestCase):
     view_class = MultiplePermissionsRequiredView
@@ -459,7 +470,7 @@ class TestMultiplePermissionsRequiredMixin(
         req = self.build_request(user=user)
 
         resp = self.dispatch_view(req, permissions=permissions)
-        self.assertEqual('OK', force_text(resp.content))
+        self.assertEqual('OK', force_string(resp.content))
 
         user = UserFactory(permissions=['auth.add_user'])
         with self.assertRaises(PermissionDenied):
@@ -476,7 +487,7 @@ class TestMultiplePermissionsRequiredMixin(
         req = self.build_request(user=user)
 
         resp = self.dispatch_view(req, permissions=permissions)
-        self.assertEqual('OK', force_text(resp.content))
+        self.assertEqual('OK', force_string(resp.content))
 
         user = UserFactory(permissions=[])
         with self.assertRaises(PermissionDenied):
@@ -485,6 +496,7 @@ class TestMultiplePermissionsRequiredMixin(
                 permissions=permissions)
 
 
+@pytest.mark.django_db
 class TestSuperuserRequiredMixin(_TestAccessBasicsMixin, test.TestCase):
     view_class = SuperuserRequiredView
     view_url = '/superuser_required/'
@@ -496,6 +508,7 @@ class TestSuperuserRequiredMixin(_TestAccessBasicsMixin, test.TestCase):
         return UserFactory()
 
 
+@pytest.mark.django_db
 class TestStaffuserRequiredMixin(_TestAccessBasicsMixin, test.TestCase):
     view_class = StaffuserRequiredView
     view_url = '/staffuser_required/'
@@ -507,6 +520,7 @@ class TestStaffuserRequiredMixin(_TestAccessBasicsMixin, test.TestCase):
         return UserFactory()
 
 
+@pytest.mark.django_db
 class TestGroupRequiredMixin(_TestAccessBasicsMixin, test.TestCase):
     view_class = GroupRequiredView
     view_url = '/group_required/'
@@ -532,7 +546,7 @@ class TestGroupRequiredMixin(_TestAccessBasicsMixin, test.TestCase):
         self.client.login(username=user.username, password='asdf1234')
         resp = self.client.get(self.view_url)
         self.assertEqual(200, resp.status_code)
-        self.assertEqual('OK', force_text(resp.content))
+        self.assertEqual('OK', force_string(resp.content))
 
     def test_with_group_list(self):
         group_list = ['test_group', 'editors']
@@ -544,7 +558,7 @@ class TestGroupRequiredMixin(_TestAccessBasicsMixin, test.TestCase):
         self.client.login(username=user.username, password='asdf1234')
         resp = self.client.get(self.view_url)
         self.assertEqual(200, resp.status_code)
-        self.assertEqual('OK', force_text(resp.content))
+        self.assertEqual('OK', force_string(resp.content))
         self.view_class.group_required = 'test_group'
         self.assertEqual('test_group', self.view_class.group_required)
 
@@ -553,7 +567,7 @@ class TestGroupRequiredMixin(_TestAccessBasicsMixin, test.TestCase):
         self.client.login(username=user.username, password='asdf1234')
         resp = self.client.get(self.view_url)
         self.assertEqual(200, resp.status_code)
-        self.assertEqual('OK', force_text(resp.content))
+        self.assertEqual('OK', force_string(resp.content))
 
     def test_improperly_configured(self):
         view = self.view_class()
@@ -578,11 +592,12 @@ class TestGroupRequiredMixin(_TestAccessBasicsMixin, test.TestCase):
         self.client.login(username=user.username, password='asdf1234')
         resp = self.client.get(self.view_url)
         self.assertEqual(200, resp.status_code)
-        self.assertEqual('OK', force_text(resp.content))
+        self.assertEqual('OK', force_string(resp.content))
         self.view_class.group_required = 'test_group'
         self.assertEqual('test_group', self.view_class.group_required)
 
 
+@pytest.mark.django_db
 class TestUserPassesTestMixin(_TestAccessBasicsMixin, test.TestCase):
     view_class = UserPassesTestView
     view_url = '/user_passes_test/'
@@ -603,7 +618,7 @@ class TestUserPassesTestMixin(_TestAccessBasicsMixin, test.TestCase):
         resp = self.client.get(self.view_url)
 
         self.assertEqual(200, resp.status_code)
-        self.assertEqual('OK', force_text(resp.content))
+        self.assertEqual('OK', force_string(resp.content))
 
     def test_with_user_not_pass(self):
         user = self.build_authorized_user(is_superuser=True)
@@ -625,13 +640,12 @@ class TestUserPassesTestMixin(_TestAccessBasicsMixin, test.TestCase):
                 raise_exception=True)
 
 
+@pytest.mark.django_db
 class TestSSLRequiredMixin(test.TestCase):
     view_class = SSLRequiredView
     view_url = '/sslrequired/'
 
-    @pytest.mark.skipif(DJANGO_VERSION[:2] < (1, 9),
-                        reason='Django 1.9 and above behave differently')
-    def test_ssl_redirection_django_19_up(self):
+    def test_ssl_redirection(self):
         self.view_url = 'https://testserver' + self.view_url
         self.view_class.raise_exception = False
         resp = self.client.get(self.view_url)
@@ -640,28 +654,6 @@ class TestSSLRequiredMixin(test.TestCase):
         self.assertEqual(200, resp.status_code)
         self.assertEqual('https', resp.request.get('wsgi.url_scheme'))
 
-    @pytest.mark.skipif(DJANGO_VERSION[:2] < (1, 7),
-                        reason='Django 1.6 and below behave differently')
-    @pytest.mark.skipif(DJANGO_VERSION[:2] > (1, 8),
-                        reason='Django 1.6 and below behave differently')
-    def test_ssl_redirection_django_17_up(self):
-        self.view_class.raise_exception = False
-        resp = self.client.get(self.view_url)
-        self.assertRedirects(resp, self.view_url, status_code=301)
-        resp = self.client.get(self.view_url, follow=True)
-        self.assertEqual(200, resp.status_code)
-        self.assertEqual('https', resp.request.get('wsgi.url_scheme'))
-
-    @pytest.mark.skipif(DJANGO_VERSION[:2] > (1, 6),
-                        reason='Django 1.7 and above behave differently')
-    def test_ssl_redirection_django_16_down(self):
-        self.view_class.raise_exception = False
-        resp = self.client.get(self.view_url)
-        self.assertEqual(301, resp.status_code)
-        resp = self.client.get(self.view_url, follow=True)
-        self.assertEqual(200, resp.status_code)
-        self.assertEqual('https', resp.request.get('wsgi.url_scheme'))
-
     def test_raises_exception(self):
         self.view_class.raise_exception = True
         resp = self.client.get(self.view_url)
@@ -673,25 +665,14 @@ class TestSSLRequiredMixin(test.TestCase):
         resp = self.client.get(self.view_url)
         self.assertEqual(200, resp.status_code)
 
-    @pytest.mark.skipif(
-        DJANGO_VERSION[:2] < (1, 7),
-        reason='Djanog 1.6 and below does not have the secure=True option')
-    def test_https_does_not_redirect_django_17_up(self):
+    def test_https_does_not_redirect(self):
         self.view_class.raise_exception = False
         resp = self.client.get(self.view_url, secure=True)
         self.assertEqual(200, resp.status_code)
         self.assertEqual('https', resp.request.get('wsgi.url_scheme'))
 
-    @pytest.mark.skipif(
-        DJANGO_VERSION[:2] > (1, 6),
-        reason='Django 1.7 and above have secure=True option, below does not')
-    def test_https_does_not_redirect_django_16_down(self):
-        self.view_class.raise_exception = False
-        resp = self.client.get(self.view_url, **{'wsgi.url_scheme': 'https'})
-        self.assertEqual(200, resp.status_code)
-        self.assertEqual('https', resp.request.get('wsgi.url_scheme'))
-
 
+@pytest.mark.django_db
 class TestRecentLoginRequiredMixin(test.TestCase):
     """
     Tests for RecentLoginRequiredMixin.
@@ -703,22 +684,25 @@ class TestRecentLoginRequiredMixin(test.TestCase):
     def test_recent_login(self):
         self.view_class.max_last_login_delta = 1800
         last_login = datetime.datetime.now()
+        last_login = make_aware(last_login, get_current_timezone())
         user = UserFactory(last_login=last_login)
         self.client.login(username=user.username, password='asdf1234')
         resp = self.client.get(self.recent_view_url)
         assert resp.status_code == 200
-        assert force_text(resp.content) == 'OK'
+        assert force_string(resp.content) == 'OK'
 
     def test_outdated_login(self):
         self.view_class.max_last_login_delta = 0
         last_login = datetime.datetime.now() - datetime.timedelta(hours=2)
+        last_login = make_aware(last_login, get_current_timezone())
         user = UserFactory(last_login=last_login)
         self.client.login(username=user.username, password='asdf1234')
         resp = self.client.get(self.outdated_view_url)
         assert resp.status_code == 302
-        
+
     def test_not_logged_in(self):
         last_login = datetime.datetime.now()
+        last_login = make_aware(last_login, get_current_timezone())
         user = UserFactory(last_login=last_login)
         resp = self.client.get(self.recent_view_url)
         assert resp.status_code != 200
