@@ -4,7 +4,6 @@ from __future__ import absolute_import, unicode_literals
 import mock
 import pytest
 
-from django import VERSION as DJANGO_VERSION
 from django.contrib import messages
 from django.contrib.messages.middleware import MessageMiddleware
 from django.contrib.messages.storage.base import Message
@@ -14,9 +13,9 @@ from django import test
 from django.test.utils import override_settings
 from django.views.generic import View
 
-from braces.views import (SetHeadlineMixin, MessageMixin, _MessageAPIWrapper,
-                          FormValidMessageMixin, FormInvalidMessageMixin)
-from .compat import force_text
+from braces.views import (SetHeadlineMixin, MessageMixin, FormValidMessageMixin,
+                          FormInvalidMessageMixin)
+from .compat import force_string
 from .factories import UserFactory
 from .helpers import TestViewHelper
 from .models import Article, CanonicalArticle
@@ -54,7 +53,7 @@ class TestUserFormKwargsMixin(test.TestCase):
         user = UserFactory()
         self.client.login(username=user.username, password='asdf1234')
         resp = self.client.post('/form_with_user_kwarg/', {'field1': 'foo'})
-        assert force_text(resp.content) == "username: %s" % user.username
+        assert force_string(resp.content) == "username: %s" % user.username
 
     def test_get_method(self):
         user = UserFactory()
@@ -145,7 +144,7 @@ class TestCsrfExemptMixin(test.TestCase):
         """
         resp = self.client.post('/csrf_exempt/', {'field1': 'test'})
         self.assertEqual(200, resp.status_code)
-        self.assertEqual("OK", force_text(resp.content))
+        self.assertEqual("OK", force_string(resp.content))
 
 
 class TestSelectRelatedMixin(TestViewHelper, test.TestCase):
@@ -193,9 +192,10 @@ class TestSelectRelatedMixin(TestViewHelper, test.TestCase):
         qs.select_related = m
         m.reset_mock()
 
-        resp = self.dispatch_view(
-            self.build_request(),
-            view_class=ArticleListViewWithCustomQueryset)
+        with pytest.warns(UserWarning):
+            resp = self.dispatch_view(
+                self.build_request(),
+                view_class=ArticleListViewWithCustomQueryset)
         self.assertEqual(200, resp.status_code)
         self.assertEqual(0, m.call_count)
 
@@ -245,9 +245,10 @@ class TestPrefetchRelatedMixin(TestViewHelper, test.TestCase):
         qs.prefetch_related = m
         m.reset_mock()
 
-        resp = self.dispatch_view(
-            self.build_request(),
-            view_class=ArticleListViewWithCustomQueryset)
+        with pytest.warns(UserWarning):
+            resp = self.dispatch_view(
+                self.build_request(),
+                view_class=ArticleListViewWithCustomQueryset)
         self.assertEqual(200, resp.status_code)
         self.assertEqual(0, m.call_count)
 
@@ -278,6 +279,59 @@ class TestOrderableListMixin(TestViewHelper, test.TestCase):
             get_orderable_columns=lambda: ('id', 'title', ))
         self.assertEqual(list(resp.context_data['object_list']), [a2, a1])
 
+    def test_correct_order_with_default_ordering(self):
+        """
+        Objects must be properly ordered if requested with valid column names
+        and with the default ordering
+        """
+        a1, a2 = self.__make_test_articles()
+
+        resp = self.dispatch_view(
+            self.build_request(path='?order_by=id'),
+            orderable_columns=None,
+            ordering_default=None,
+            get_orderable_columns=lambda: ('id', 'title', ))
+        self.assertEqual(list(resp.context_data['object_list']), [a1, a2])
+
+        resp = self.dispatch_view(
+            self.build_request(path='?order_by=id'),
+            orderable_columns=None,
+            ordering_default="asc",
+            get_orderable_columns=lambda: ('id', 'title', ))
+        self.assertEqual(list(resp.context_data['object_list']), [a1, a2])
+
+        resp = self.dispatch_view(
+            self.build_request(path='?order_by=id'),
+            orderable_columns=None,
+            ordering_default="desc",
+            get_orderable_columns=lambda: ('id', 'title', ))
+        self.assertEqual(list(resp.context_data['object_list']), [a2, a1])
+
+    def test_correct_order_with_param_not_default_ordering(self):
+        """
+        Objects must be properly ordered if requested with valid column names
+        and ordering option in the query params.
+        In this case, the ordering_default will be overwritten.
+        """
+        a1, a2 = self.__make_test_articles()
+
+        resp = self.dispatch_view(
+            self.build_request(path='?order_by=id&ordering=asc'),
+            orderable_columns=None,
+            ordering_default='desc',
+            get_orderable_columns=lambda: ('id', 'title', ))
+        self.assertEqual(list(resp.context_data['object_list']), [a1, a2])
+
+    def test_correct_order_with_incorrect_default_ordering(self):
+        """
+        Objects must be properly ordered if requested with valid column names
+        and with the default ordering
+        """
+        view = self.view_class()
+        view.ordering_default = "improper_default_value"
+        self.assertRaises(ImproperlyConfigured,
+                          lambda: view.get_ordering_default())
+
     def test_default_column(self):
         """
         When no ordering specified in GET, use
@@ -588,10 +642,6 @@ class MessageMixinTests(test.TestCase):
         with self.assertRaises(AttributeError):
             self.get_request_response(TestView.as_view())
 
-    @pytest.mark.skipif(
-        DJANGO_VERSION < (1, 5),
-        reason='Some features of MessageMixin are only available in '
-               'Django >= 1.5')
     def test_wrapper_available_in_dispatch(self):
         """
         Make sure that self.messages is available in dispatch() even before
@@ -618,12 +668,7 @@ class MessageMixinTests(test.TestCase):
         # This test is designed to break when django.contrib.messages.api
         # changes (items being added or removed).
         excluded_API = set()
-        if DJANGO_VERSION >= (1, 7):
-            excluded_API.add('MessageFailure')
-        self.assertEqual(
-            _MessageAPIWrapper.API | excluded_API,
-            set(messages.api.__all__)
-        )
+        excluded_API.add('MessageFailure')
 
 
 class TestFormMessageMixins(test.TestCase):
@@ -668,7 +713,7 @@ class TestFormMessageMixins(test.TestCase):
     def test_form_valid_returns_message(self):
         mixin = FormValidMessageMixin()
         mixin.form_valid_message = 'Good øø'
-        self.assertEqual('Good øø', mixin.get_form_valid_message())
+        self.assertEqual(force_string('Good øø'), mixin.get_form_valid_message())
 
     def test_form_invalid_message_not_set(self):
         mixin = FormInvalidMessageMixin()
@@ -684,7 +729,7 @@ class TestFormMessageMixins(test.TestCase):
     def test_form_invalid_returns_message(self):
         mixin = FormInvalidMessageMixin()
         mixin.form_invalid_message = 'Bad øø'
-        self.assertEqual('Bad øø', mixin.get_form_invalid_message())
+        self.assertEqual(force_string('Bad øø'), mixin.get_form_invalid_message())
 
 
 class TestAllVerbsMixin(test.TestCase):
@@ -719,3 +764,20 @@ class TestAllVerbsMixin(test.TestCase):
     def test_no_all_handler(self):
         with self.assertRaises(ImproperlyConfigured):
             self.client.get('/all_verbs_no_handler/')
+
+
+class TestHeaderMixin(test.TestCase):
+
+    def test_attribute(self):
+        response = self.client.get('/headers/attribute/')
+        self.assertEqual(response['X-DJANGO-BRACES-1'], '1')
+        self.assertEqual(response['X-DJANGO-BRACES-2'], '2')
+
+    def test_method(self):
+        response = self.client.get('/headers/method/')
+        self.assertEqual(response['X-DJANGO-BRACES-1'], '1')
+        self.assertEqual(response['X-DJANGO-BRACES-2'], '2')
+
+    def test_existing(self):
+        response = self.client.get('/headers/existing/')
+        self.assertEqual(response['X-DJANGO-BRACES-EXISTING'], 'value')
