@@ -1,11 +1,11 @@
 from __future__ import absolute_import
 
+from django.core.exceptions import ImproperlyConfigured
+from django.contrib.auth.views import LoginView
 from . import views
-from .compat import patterns, include, url
+from .compat import include, url, patterns_compat
 
-
-urlpatterns = patterns(
-    '',
+urlpatterns = [
     # LoginRequiredMixin tests
     url(r'^login_required/$', views.LoginRequiredView.as_view()),
 
@@ -34,8 +34,6 @@ urlpatterns = patterns(
     url(r'^article-canonical/(?P<pk>\d+)-(?P<slug>[-\w]+)/$',
         views.CanonicalSlugDetailView.as_view(),
         name="canonical_slug"),
-    url(r'^article-canonical-namespaced/',
-        include('tests.urls_namespaced', namespace='some_namespace')),
     url(r'^article-canonical-override/(?P<pk>\d+)-(?P<slug>[-\w]+)/$',
         views.OverriddenCanonicalSlugDetailView.as_view(),
         name="canonical_override"),
@@ -110,12 +108,27 @@ urlpatterns = patterns(
     # RecentLoginRequiredMixin tests
     url(r'^recent_login/$', views.RecentLoginRequiredView.as_view()),
     url(r'^outdated_login/$', views.RecentLoginRequiredView.as_view()),
-)
 
+    # HeaderMixin tests
+    url(r'^headers/attribute/$', views.AttributeHeaderView.as_view()),
+    url(r'^headers/method/$', views.MethodHeaderView.as_view()),
+    url(r'^headers/existing/$', views.ExistingHeaderView.as_view()),
+]
 
-urlpatterns += patterns(
-    'django.contrib.auth.views',
-    # login page, required by some tests
-    url(r'^accounts/login/$', 'login', {'template_name': 'blank.html'}),
-    url(r'^auth/login/$', 'login', {'template_name': 'blank.html'}),
-)
+urlpatterns += [
+    url(r'^accounts/login/$', LoginView.as_view(template_name='blank.html')),
+    url(r'^auth/login/$', LoginView.as_view(template_name='blank.html')),
+]
+try:
+    urlpatterns += [
+        url(r'^article-canonical-namespaced/',
+            include(('tests.urls_namespaced', 'tests'),
+                    namespace='some_namespace')),
+    ]
+except ImproperlyConfigured:
+    urlpatterns += [
+        url(r'^article-canonical-namespaced/',
+            include('tests.urls_namespaced', namespace='some_namespace')),
+    ]
+
+urlpatterns = patterns_compat(urlpatterns)
